==> haskell-wai-extra-3.0.25-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.25
id: wai-extra-3.0.25-KjzaNfAngnH9G0UuV5t0UC
key: wai-extra-3.0.25-KjzaNfAngnH9G0UuV5t0UC
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
abi: 5da64960b2ccfcbf93330a54867f332e
exposed: True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.Vhost Network.Wai.Parse Network.Wai.Request
    Network.Wai.Test Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/wai-extra-3.0.25
library-dirs: /usr/lib/ghc-8.6.4/site-local/wai-extra-3.0.25
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/wai-extra-3.0.25
hs-libraries: HSwai-extra-3.0.25-KjzaNfAngnH9G0UuV5t0UC
depends:
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP base-4.12.0.0
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 deepseq-1.4.4.0
    directory-1.3.3.0 fast-logger-2.4.15-1nBSFCOZiNwHPgWMlH3CM3
    http-types-0.12.3-D3aEnVjdeLuS27pc1eWXD
    iproute-1.7.7-H127wPQtNGPCy98ATnFDeC
    network-2.8.0.0-79Coriq35AYDs1MobOTL51
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    resourcet-1.2.2-6zBKJcCUqdeLbP1UFGIV0t
    streaming-commons-0.2.1.0-19YdMWMsOBj89hcZWt2P2v text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    vault-0.3.1.2-3mWiTKQJgRW12cmmatOcbu
    void-0.7.2-1ijpCmwDTXMGDRdU43YY14 wai-3.2.2-74cWC9elHhvLTIAdmFqvG
    wai-logger-2.3.4-3CXwV70HgTuHawCGvRXjwy
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.0.25-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.25
id: wai-extra-3.0.25-Lc1ZfEabd1pLfSmuIEZWzL
key: wai-extra-3.0.25-Lc1ZfEabd1pLfSmuIEZWzL
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
abi: 251e6093d129de9dd5c9f5a79d9d504b
exposed: True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.Jsonp Network.Wai.Middleware.Local
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.Vhost Network.Wai.Parse Network.Wai.Request
    Network.Wai.Test Network.Wai.Test.Internal Network.Wai.UrlMap
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-extra-3.0.25
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-extra-3.0.25
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-extra-3.0.25
hs-libraries: HSwai-extra-3.0.25-Lc1ZfEabd1pLfSmuIEZWzL
depends:
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP base-4.12.0.0
    base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 deepseq-1.4.4.0
    directory-1.3.3.0 fast-logger-2.4.15-1nBSFCOZiNwHPgWMlH3CM3
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    iproute-1.7.7-208U3JVoXMFCaA62jgUbOB
    network-2.8.0.0-g7zeLS1MQKFu6rNI1xGwt
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    resourcet-1.2.2-6zBKJcCUqdeLbP1UFGIV0t
    streaming-commons-0.2.1.0-3vwzF3cN9Vd9YIu71UgnpO text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2 unix-2.7.2.2
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    vault-0.3.1.2-3mWiTKQJgRW12cmmatOcbu
    void-0.7.2-1ijpCmwDTXMGDRdU43YY14 wai-3.2.2-GrHvuMWBg0KAzl6COLfHLZ
    wai-logger-2.3.4-I62eIKyj72NEACiVBIEGIs
    word8-0.1.3-Hij9fyb7arJ9SXwAnMfmS0
    zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
